summaryrefslogtreecommitdiffstats
path: root/lib/antlr
diff options
context:
space:
mode:
Diffstat (limited to 'lib/antlr')
-rw-r--r--lib/antlr/antlr/AST.hpp6
-rw-r--r--lib/antlr/antlr/ASTFactory.hpp2
-rw-r--r--lib/antlr/antlr/BaseAST.hpp4
-rw-r--r--lib/antlr/antlr/CharScanner.hpp2
-rw-r--r--lib/antlr/antlr/TokenStreamBasicFilter.hpp2
-rw-r--r--lib/antlr/antlr/TokenStreamHiddenTokenFilter.hpp2
-rw-r--r--lib/antlr/antlr/TokenStreamRewriteEngine.hpp28
-rw-r--r--lib/antlr/src/ASTFactory.cpp10
-rw-r--r--lib/antlr/src/BaseAST.cpp12
-rw-r--r--lib/antlr/src/Makefile.am2
-rw-r--r--lib/antlr/src/TokenStreamBasicFilter.cpp4
-rw-r--r--lib/antlr/src/TokenStreamHiddenTokenFilter.cpp4
12 files changed, 39 insertions, 39 deletions
diff --git a/lib/antlr/antlr/AST.hpp b/lib/antlr/antlr/AST.hpp
index b01a60a9..a25144f9 100644
--- a/lib/antlr/antlr/AST.hpp
+++ b/lib/antlr/antlr/AST.hpp
@@ -63,10 +63,10 @@ public:
/// Add a node to the end of the child list for this node
virtual void addChild(RefAST c) = 0;
- /// Get the number of children. Returns 0 if the node is a leaf
+ /// Get the number of tqchildren. Returns 0 if the node is a leaf
virtual size_t getNumberOfChildren() const = 0;
- /// Get the first child of this node; null if no children
+ /// Get the first child of this node; null if no tqchildren
virtual RefAST getFirstChild() const = 0;
/// Get the next sibling in line after this one
virtual RefAST getNextSibling() const = 0;
@@ -151,7 +151,7 @@ extern ANTLR_API RefAST nullAST;
extern ANTLR_API AST* const nullASTptr;
#ifdef NEEDS_OPERATOR_LESS_THAN
-// RK: apparently needed by MSVC and a SUN CC, up to and including
+// RK: aptqparently needed by MSVC and a SUN CC, up to and including
// 2.7.2 this was undefined ?
inline bool operator<( RefAST l, RefAST r )
{
diff --git a/lib/antlr/antlr/ASTFactory.hpp b/lib/antlr/antlr/ASTFactory.hpp
index 968ab6c5..0fb78dc1 100644
--- a/lib/antlr/antlr/ASTFactory.hpp
+++ b/lib/antlr/antlr/ASTFactory.hpp
@@ -86,7 +86,7 @@ public:
RefAST dupTree(RefAST t);
/** Make a tree from a list of nodes. The first element in the
* array is the root. If the root is null, then the tree is
- * a simple list not a tree. Handles null children nodes correctly.
+ * a simple list not a tree. Handles null tqchildren nodes correctly.
* For example, make(a, b, null, c) yields tree (a b c). make(null,a,b)
* yields tree (nil a b).
*/
diff --git a/lib/antlr/antlr/BaseAST.hpp b/lib/antlr/antlr/BaseAST.hpp
index 1bfc4e56..3a88db32 100644
--- a/lib/antlr/antlr/BaseAST.hpp
+++ b/lib/antlr/antlr/BaseAST.hpp
@@ -96,7 +96,7 @@ public:
*/
virtual size_t getNumberOfChildren() const;
- /// Get the first child of this node; null if no children
+ /// Get the first child of this node; null if no tqchildren
virtual RefAST getFirstChild() const
{
return RefAST(down);
@@ -118,7 +118,7 @@ public:
return 0;
}
- /// Remove all children
+ /// Remove all tqchildren
virtual void removeChildren()
{
down = static_cast<BaseAST*>(static_cast<AST*>(nullAST));
diff --git a/lib/antlr/antlr/CharScanner.hpp b/lib/antlr/antlr/CharScanner.hpp
index f7e58520..5f2b8e9e 100644
--- a/lib/antlr/antlr/CharScanner.hpp
+++ b/lib/antlr/antlr/CharScanner.hpp
@@ -43,7 +43,7 @@ class ANTLR_API CharScanner;
ANTLR_C_USING(tolower)
#ifdef ANTLR_REALLY_NO_STRCASECMP
-// Apparently, neither strcasecmp nor stricmp is standard, and Codewarrior
+// Aptqparently, neither strcasecmp nor stricmp is standard, and Codewarrior
// on the mac has neither...
inline int strcasecmp(const char *s1, const char *s2)
{
diff --git a/lib/antlr/antlr/TokenStreamBasicFilter.hpp b/lib/antlr/antlr/TokenStreamBasicFilter.hpp
index bcdb131c..353014a4 100644
--- a/lib/antlr/antlr/TokenStreamBasicFilter.hpp
+++ b/lib/antlr/antlr/TokenStreamBasicFilter.hpp
@@ -34,7 +34,7 @@ public:
void discard(int ttype);
- void discard(const BitSet& mask);
+ void discard(const BitSet& tqmask);
RefToken nextToken();
};
diff --git a/lib/antlr/antlr/TokenStreamHiddenTokenFilter.hpp b/lib/antlr/antlr/TokenStreamHiddenTokenFilter.hpp
index ed007a7a..867a4101 100644
--- a/lib/antlr/antlr/TokenStreamHiddenTokenFilter.hpp
+++ b/lib/antlr/antlr/TokenStreamHiddenTokenFilter.hpp
@@ -69,7 +69,7 @@ public:
void hide(int m);
- void hide(const BitSet& mask);
+ void hide(const BitSet& tqmask);
protected:
RefToken LA(int i);
diff --git a/lib/antlr/src/ASTFactory.cpp b/lib/antlr/src/ASTFactory.cpp
index 98ce6b7a..a255ca10 100644
--- a/lib/antlr/src/ASTFactory.cpp
+++ b/lib/antlr/src/ASTFactory.cpp
@@ -217,7 +217,7 @@ RefAST ASTFactory::dupList(RefAST t)
RefAST ASTFactory::dupTree(RefAST t)
{
RefAST result = dup(t); // make copy of root
- // copy all children of root.
+ // copy all tqchildren of root.
if( t )
result->setFirstChild( dupList(t->getFirstChild()) );
return result;
@@ -225,7 +225,7 @@ RefAST ASTFactory::dupTree(RefAST t)
/** Make a tree from a list of nodes. The first element in the
* array is the root. If the root is null, then the tree is
- * a simple list not a tree. Handles null children nodes correctly.
+ * a simple list not a tree. Handles null tqchildren nodes correctly.
* For example, make(a, b, null, c) yields tree (a b c). make(null,a,b)
* yields tree (nil a b).
*/
@@ -240,7 +240,7 @@ RefAST ASTFactory::make(ANTLR_USE_NAMESPACE(std)vector<RefAST>& nodes)
if( root )
root->setFirstChild(RefAST(nullASTptr)); // don't leave any old pointers set
- // link in children;
+ // link in tqchildren;
for( unsigned int i = 1; i < nodes.size(); i++ )
{
if ( nodes[i] == 0 ) // ignore null nodes
@@ -336,7 +336,7 @@ void ASTFactory::loadChildren( ANTLR_USE_NAMESPACE(std)istream& infile,
{
char ch;
- for(;;) // for all children of this node....
+ for(;;) // for all tqchildren of this node....
{
eatwhite(infile);
@@ -438,7 +438,7 @@ RefAST ASTFactory::LoadAST( ANTLR_USE_NAMESPACE(std)istream& infile )
infile.get(ch);
// now if we have a '/' here it's a single node. If it's a '>' we get
- // a tree with children
+ // a tree with tqchildren
if( ch == '/' )
{
diff --git a/lib/antlr/src/BaseAST.cpp b/lib/antlr/src/BaseAST.cpp
index f10f1e16..17d8de68 100644
--- a/lib/antlr/src/BaseAST.cpp
+++ b/lib/antlr/src/BaseAST.cpp
@@ -47,7 +47,7 @@ void BaseAST::doWorkForFindAll(
(!partialMatch && sibling->equalsTree(target)) ) {
v.push_back(sibling);
}
- // regardless of match or not, check any children for matches
+ // regardless of match or not, check any tqchildren for matches
if ( sibling->getFirstChild() ) {
RefBaseAST(sibling->getFirstChild())->doWorkForFindAll(v, target, partialMatch);
}
@@ -70,7 +70,7 @@ bool BaseAST::equalsList(RefAST t) const
// as a quick optimization, check roots first.
if (!sibling->equals(t))
return false;
- // if roots match, do full list match test on children.
+ // if roots match, do full list match test on tqchildren.
if (sibling->getFirstChild()) {
if (!sibling->getFirstChild()->equalsList(t->getFirstChild()))
return false;
@@ -103,7 +103,7 @@ bool BaseAST::equalsListPartial(RefAST sub) const
// as a quick optimization, check roots first.
if (!sibling->equals(sub))
return false;
- // if roots match, do partial list match test on children.
+ // if roots match, do partial list match test on tqchildren.
if (sibling->getFirstChild())
if (!sibling->getFirstChild()->equalsListPartial(sub->getFirstChild()))
return false;
@@ -125,7 +125,7 @@ bool BaseAST::equalsTree(RefAST t) const
// check roots first
if (!equals(t))
return false;
- // if roots match, do full list match test on children.
+ // if roots match, do full list match test on tqchildren.
if (getFirstChild()) {
if (!getFirstChild()->equalsList(t->getFirstChild()))
return false;
@@ -149,7 +149,7 @@ bool BaseAST::equalsTreePartial(RefAST sub) const
// check roots first
if (!equals(sub))
return false;
- // if roots match, do full list partial match test on children.
+ // if roots match, do full list partial match test on tqchildren.
if (getFirstChild())
if (!getFirstChild()->equalsListPartial(sub->getFirstChild()))
return false;
@@ -256,7 +256,7 @@ void BaseAST::toStream( ANTLR_USE_NAMESPACE(std)ostream& out ) const
if( need_close_tag )
{
- // got children so write them...
+ // got tqchildren so write them...
if( node->getFirstChild() != 0 )
node->getFirstChild()->toStream( out );
diff --git a/lib/antlr/src/Makefile.am b/lib/antlr/src/Makefile.am
index b1af9fca..3d3b94af 100644
--- a/lib/antlr/src/Makefile.am
+++ b/lib/antlr/src/Makefile.am
@@ -1,6 +1,6 @@
# Make #include <antlr/xxx> work..
-INCLUDES = -I$(srcdir)/..
+INCLUDES = -I$(srcdir)/.. $(all_includes)
KDE_CXXFLAGS = $(USE_EXCEPTIONS)
noinst_LTLIBRARIES = libantlr.la
diff --git a/lib/antlr/src/TokenStreamBasicFilter.cpp b/lib/antlr/src/TokenStreamBasicFilter.cpp
index 982e8645..ac6156da 100644
--- a/lib/antlr/src/TokenStreamBasicFilter.cpp
+++ b/lib/antlr/src/TokenStreamBasicFilter.cpp
@@ -24,9 +24,9 @@ void TokenStreamBasicFilter::discard(int ttype)
discardMask.add(ttype);
}
-void TokenStreamBasicFilter::discard(const BitSet& mask)
+void TokenStreamBasicFilter::discard(const BitSet& tqmask)
{
- discardMask = mask;
+ discardMask = tqmask;
}
RefToken TokenStreamBasicFilter::nextToken()
diff --git a/lib/antlr/src/TokenStreamHiddenTokenFilter.cpp b/lib/antlr/src/TokenStreamHiddenTokenFilter.cpp
index 431df0c3..90d48d5a 100644
--- a/lib/antlr/src/TokenStreamHiddenTokenFilter.cpp
+++ b/lib/antlr/src/TokenStreamHiddenTokenFilter.cpp
@@ -94,9 +94,9 @@ void TokenStreamHiddenTokenFilter::hide(int m)
hideMask.add(m);
}
-void TokenStreamHiddenTokenFilter::hide(const BitSet& mask)
+void TokenStreamHiddenTokenFilter::hide(const BitSet& tqmask)
{
- hideMask = mask;
+ hideMask = tqmask;
}
RefToken TokenStreamHiddenTokenFilter::LA(int)
diff --git a/lib/antlr/antlr/TokenStreamRewriteEngine.hpp b/lib/antlr/antlr/TokenStreamRewriteEngine.hpp
index 9fab08c2..6aa948fe 100644
--- a/lib/antlr/antlr/TokenStreamRewriteEngine.hpp
+++ b/lib/antlr/antlr/TokenStreamRewriteEngine.hpp
@@ -34,7 +34,7 @@ namespace antlr {
* Useful for dumping out the input stream exactly after doing some
* augmentation or other manipulations. Tokens are index from 0..n-1
*
* You can insert stuff, replace, and delete chunks. Note that the
* operations are done lazily--only if you convert the buffer to a
* String. This is very efficient because you are not moving data around
* all the time. As the buffer of tokens is converted to strings, the
@@ -262,43 +262,43 @@ public:
addToSortedRewriteList(programName, new InsertBeforeOp(index,text));
}
- void replace(size_t index, const ANTLR_USE_NAMESPACE(std)string& text)
+ void tqreplace(size_t index, const ANTLR_USE_NAMESPACE(std)string& text)
{
- replace(DEFAULT_PROGRAM_NAME, index, index, text);
+ tqreplace(DEFAULT_PROGRAM_NAME, index, index, text);
}
- void replace( size_t from, size_t to,
+ void tqreplace( size_t from, size_t to,
const ANTLR_USE_NAMESPACE(std)string& text)
{
- replace(DEFAULT_PROGRAM_NAME, from, to, text);
+ tqreplace(DEFAULT_PROGRAM_NAME, from, to, text);
}
- void replace( RefTokenWithIndex indexT,
+ void tqreplace( RefTokenWithIndex indexT,
const ANTLR_USE_NAMESPACE(std)string& text )
{
- replace(DEFAULT_PROGRAM_NAME, indexT->getIndex(), indexT->getIndex(), text);
+ tqreplace(DEFAULT_PROGRAM_NAME, indexT->getIndex(), indexT->getIndex(), text);
}
- void replace( RefTokenWithIndex from,
+ void tqreplace( RefTokenWithIndex from,
RefTokenWithIndex to,
const ANTLR_USE_NAMESPACE(std)string& text )
{
- replace(DEFAULT_PROGRAM_NAME, from, to, text);
+ tqreplace(DEFAULT_PROGRAM_NAME, from, to, text);
}
- void replace(const ANTLR_USE_NAMESPACE(std)string& programName,
+ void tqreplace(const ANTLR_USE_NAMESPACE(std)string& programName,
size_t from, size_t to,
const ANTLR_USE_NAMESPACE(std)string& text )
{
addToSortedRewriteList(programName,new ReplaceOp(from, to, text));
}
- void replace( const ANTLR_USE_NAMESPACE(std)string& programName,
+ void tqreplace( const ANTLR_USE_NAMESPACE(std)string& programName,
RefTokenWithIndex from,
RefTokenWithIndex to,
const ANTLR_USE_NAMESPACE(std)string& text )
{
- replace(programName,
+ tqreplace(programName,
from->getIndex(),
to->getIndex(),
text);
@@ -323,13 +323,13 @@ public:
void remove( const ANTLR_USE_NAMESPACE(std)string& programName,
size_t from, size_t to)
{
- replace(programName,from,to,"");
+ tqreplace(programName,from,to,"");
}
void remove( const ANTLR_USE_NAMESPACE(std)string& programName,
RefTokenWithIndex from, RefTokenWithIndex to )
{
- replace(programName,from,to,"");
+ tqreplace(programName,from,to,"");
}
void discard(int ttype) {
@@ -34,7 +34,7 @@ namespace antlr {
* augmentation or other manipulations. Tokens are index from 0..n-1
*
- * You can insert stuff, replace, and delete chunks. Note that the
+ * You can insert stuff, tqreplace, and delete chunks. Note that the
* operations are done lazily--only if you convert the buffer to a
* String. This is very efficient because you are not moving data around